.. _template-objects:

Templates
=========

The `eazy.templates.Template` object provides a number of tools for working with 
population synthesis templates, e.g., from `FSPS <https://github.com/cconroy20/fsps>`_.

Templates integrated through filter bandpasses
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Redshift-dependent templates
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Additional functionality
~~~~~~~~~~~~~~~~~~~~~~~~
Smoothing and resampling...

The "Template Error Function"
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

API
~~~
.. automodapi:: eazy.templates
    :no-inheritance-diagram:
